#
# spec file for package python-pyinstaller-hooks-contrib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -%{flavor}
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-pyinstaller-hooks-contrib%{psuffix}
Version:        2024.0
Release:        1.5
Summary:        Community maintained hooks for PyInstaller
License:        Apache-2.0 OR GPL-2.0-only
URL:            https://github.com/pyinstaller/pyinstaller-hooks-contrib
Source:         https://files.pythonhosted.org/packages/source/p/pyinstaller-hooks-contrib/pyinstaller-hooks-contrib-%{version}.tar.gz
BuildRequires:  %{python_module setuptools >= 30.3.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module PyInstaller}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pyinstaller-hooks-contrib = %{version}}
BuildRequires:  %{python_module pytest}
BuildRequires:  timezone
# SECTION optional, the depending tests would be skipped without these
# most of the libraries enable only two tests, so adding just scikit-learn to run at least any tests
BuildRequires:  %{python_module scikit-learn}
# /SECTION
%endif
%python_subpackages

%description
Community maintained hooks for PyInstaller

%prep
%autosetup -p1 -n pyinstaller-hooks-contrib-%{version}

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest src/_pyinstaller_hooks_contrib/tests
%endif

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE LICENSE.APL.txt LICENSE.GPL.txt
%{python_sitelib}/_pyinstaller_hooks_contrib
%{python_sitelib}/pyinstaller_hooks_contrib-%{version}*-info
%endif

%changelog
* Tue Jan 30 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.0:
  * Add hook for ``cel-python``.
  * Add hook for ``eth_keys`` that collects package metadata for
    ``eth-keys >= 0.5.0``.
  * Add hook for ``fairscale`` to collect its source .py files for
    TorchScript/JIT.
  * Add hook for ``pygwalker`` that collects data files from the package.
  * Add hook for ``PyTaskbar``
  * Add hook for ``detectron2`` to collect its source .py files for
    TorchScript/JIT.
  * Add hook for ``fastai`` to collect its source .py files for
    TorchScript/JIT.
  * Add hook for ``fvcore.nn`` to collect its source .py files for
    TorchScript/JIT. (`#676
  * Add hook for ``langchain`` that collects data files from the
    package.
  * Add hook for ``lightning`` (PyTorch Lightning) to ensure that
    its ``version.info`` data file is collected.
  * Add hook for ``linear_operator`` to collect its source .py
    files for TorchScript/JIT.
  * Add hook for ``seedir`` that collects the ``words.txt`` data
    file from the package.
  * Add hook for ``timm`` (Hugging Face PyTorch Image Models) to
    collect its source .py files for TorchScript/JIT.
  * Add hook for ``torchaudio`` that collects dynamically-loaded
    extensions, as well as source .py files for TorchScript/JIT.
  * Add hook for ``torchtext`` that collects dynamically-loaded
    extensions, as well as source .py files for TorchScript/JIT.
  * Add hook for ``torchvision.io.image`` to ensure that
    dynamically-loaded extension, required by this module, is
    collected.
  * Add hook for ``VADER``.
  * Add hook for Hugging Face ``datasets`` to collect its source
    .py files for TorchScript/JIT.
  * Add hook for Hugging Face ``transformers``. The hook attempts
    to automatically collect the metadata of all dependencies (as
    declared in `deps` dictionary in the
    `transformers.dependency_versions_table` module), in order to
    make dependencies available at build time visible to
    ``transformers`` at run time. The hook also collects source .py
    files as some of the package's functionality uses
    TorchScript/JIT.
  * Add hooks for ``bitsandbytes``, and its dependency ``triton``.
    Both packages have dynamically-loaded extension libraries that
    need to be collected, and both require collection of source .py
    files for (``triton``'s) JIT module. Some submodules of
    ``triton`` need to be collected only as source .py files
    (bypassing PYZ archive), because the code naively assumes that
    ``__file__`` attribute points to the source .py file.
  * Add hooks for ``nvidia.*`` packages, which provide a way of
    installing CUDA via PyPI wheels
* Tue Jul 11 2023 Markéta Machová <mmachova@suse.com>
- Update to 2023.5
  * Update sklearn hooks for compatibility with scikit-learn 1.2.0 and 1.2.1.
  * Extend cv2 hook with support for OpenCV built manually from source and
    for OpenCV installed using the official Windows installer. This support
    requires PyInstaller >= 5.3 to work properly.
  * Many new hooks and hook updates, see upstream changelog
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Feb 15 2023 Daniel Garcia <daniel.garcia@suse.com>
- Disable broken sklearn tests gh#pyinstaller/pyinstaller-hooks-contrib#547
- Update to version 2023.0
  * Add hook for minecraft-launcher-lib (#536)
  * Add hook for nbt (#537)
  * Have fiona hook collect the package's data files (e.g., the projections
    database). (#541)
  * Update fiona hook for compatibility with fiona 1.9.0. (#541)
- Update to version 2022.15
  * Add a hook for easyocr, which imports recognition backends via
    imporlib.import_module() and has a number of datafiles for different
    languages.
  * Users can set which languages to include datafiles for with a hook option.
    (#530)
  * Add hook for charset-normalizer to fix ModuleNotFoundError: No module
    named 'charset_normalizer.md__mypyc'. (#534)
  * Update shapely hook for compatibility with shapely >= 2.0.0. (#527)
  * Added hooks-config.rst document which documents hook options. It is
    referred to from README.md. (#530)
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2022.14
  Add hook for cf_units. (#521)
  Add hook for cftime. (#521)
  Add hook for compliance_checker. (#521)
  Updated hooks
  Update netCDF4 hook for compatibility with v1.4.0 and later, where netcdftime has been renamed to cftime. (#521)
  Update pydantic hook to include dotenv optional dependency. (#524)
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2022.13
  * Update pyproj hook for compatibility with pyproj v3.4.0. (#505)
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2022.12
  New hooks
  * Add hook for discid. (#506)
  * Add hook for exchangelib. (#508)
- Update to versino 2022.11
  * New hooks
  Add a hook for spiceypy, which has binary files. (#482)
  Added a hook for ldfparser. (#483)
  * Updated hooks
  Extend the sounddevice and soundfile hooks to collect system-installed shared libraries in cases when the libraries are
  not bundled with the package (i.e., linux PyPI wheels, Anaconda on all OSes). (#487)
  Fix a TypeError raised by the clr hook when pythonnet dist lacks the file list metadata. (#486)
  Have clr hook check for availability of the pythonnet before trying to query its metadata. Fixes an importlib.metadata.PackageNotFoundError
  raised by the clr hook when the hook is triggered by a module or a package named clr other than the clr extension module from pythonnet. (#486)
  Have the pyqtgraph hook collect the colormap files and their license files from the package. (#501)
  Implement preliminary support for handling subprocesses used by pyqtgraph.multiprocess, for example in pyqtgraph RemoteGraphicsView widget.
  The user is still required to ensure that stdlib's multiprocessing.freeze_support is called in the entry-point script before using pyqtgraph.
  In addition, with onefile builds, the user must set the _MEIPASS2 environment variable to the value of sys._MEIPASS before using pyqtgraph. (#501)
  In clr hook for pythonnet collect the Python.Runtime.dll as a data file on non-Windows OSes to prevent errors during binary dependency analysis. (#500)
* Thu Sep 22 2022 Markéta Machová <mmachova@suse.com>
- Initial packaging (v2022.10), needed by python-PyInstaller
